@@ -2,40 +2,38 @@ import hashlib
 from secrets import token_bytes
 from typing import Any, Union
 
-from Cryptodome.Cipher import ChaCha20
-from cryptography.hazmat.primitives import serialization
 from cryptography.hazmat.primitives.asymmetric.ed25519 import (
     Ed25519PrivateKey,
     Ed25519PublicKey,
 )
 
-from ..exceptions import DecryptError, EncryptError, SignError, VerifyError
-from ..key_interface import KeyInterface
-from ..local_key import LocalKey
-from ..utils import base64url_decode, base64url_encode, pae
+from ..exceptions import DecryptError, SignError, VerifyError
+from ..key_sodium import SodiumKey
+from ..utils import base64url_encode, pae
 
 
-class V4Local(LocalKey):
+class V4Local(SodiumKey):
     """
     The key object for v4.local.
     """
 
+    _VERSION = 4
+    _TYPE = "local"
+
     def __init__(self, key: Union[str, bytes]):
 
-        super().__init__(4, "local", key)
-
+        super().__init__(key)
         if len(self._key) > 64:
             raise ValueError("key length must be up to 64 bytes.")
         return
 
-    @classmethod
-    def from_paserk(cls, paserk: str) -> KeyInterface:
-        frags = paserk.split(".")
-        if frags[0] != "k4":
-            raise ValueError("Invalid PASERK version for a v4.local key.")
-        if frags[1] != "local":
-            raise ValueError("Invalid PASERK type for a v4.local key.")
-        return cls(base64url_decode(frags[2]))
+    def to_paserk_id(self) -> str:
+        h = "k4.lid."
+        p = self.to_paserk()
+        b = hashlib.blake2b(digest_size=33)
+        b.update((h + p).encode("utf-8"))
+        d = b.digest()
+        return h + base64url_encode(d).decode("utf-8")
 
     def encrypt(
         self,
@@ -55,17 +53,13 @@ class V4Local(LocalKey):
         n2 = tmp[32:]
         ak = self._generate_hash(self._key, b"paseto-auth-key-for-aead" + nonce, 32)
 
-        try:
-            cipher = ChaCha20.new(key=ek, nonce=n2)
-            c = cipher.encrypt(payload)
-            pre_auth = pae([self.header, nonce, c, footer, implicit_assertion])
-            t = self._generate_hash(ak, pre_auth, 32)
-            token = self._header + base64url_encode(nonce + c + t)
-            if footer:
-                token += b"." + base64url_encode(footer)
-            return token
-        except Exception as err:
-            raise EncryptError("Failed to encrypt.") from err
+        c = self._encrypt(ek, n2, payload)
+        pre_auth = pae([self.header, nonce, c, footer, implicit_assertion])
+        t = self._generate_hash(ak, pre_auth, 32)
+        token = self._header + base64url_encode(nonce + c + t)
+        if footer:
+            token += b"." + base64url_encode(footer)
+        return token
 
     def decrypt(
         self, payload: bytes, footer: bytes = b"", implicit_assertion: bytes = b""
@@ -82,58 +76,26 @@ class V4Local(LocalKey):
         t2 = self._generate_hash(ak, pre_auth, 32)
         if t != t2:
             raise DecryptError("Failed to decrypt.")
-        try:
-            cipher = ChaCha20.new(key=ek, nonce=n2)
-            return cipher.decrypt(c)
-        except Exception as err:
-            raise DecryptError("Failed to decrypt.") from err
-
-    def to_paserk_id(self) -> str:
-        h = "k4.lid."
-        p = self.to_paserk()
-        b = hashlib.blake2b(digest_size=33)
-        b.update((h + p).encode("utf-8"))
-        d = b.digest()
-        return h + base64url_encode(d).decode("utf-8")
-
-    def _generate_hash(self, key: bytes, msg: bytes, size: int) -> bytes:
-
-        try:
-            h = hashlib.blake2b(key=key, digest_size=size)
-            h.update(msg)
-            return h.digest()
-        except Exception as err:
-            raise EncryptError("Failed to generate hash.") from err
+        return self._decrypt(ek, n2, c)
 
 
-class V4Public(KeyInterface):
+class V4Public(SodiumKey):
     """
     The key object for v4.public.
     """
 
+    _VERSION = 4
+    _TYPE = "public"
+
     def __init__(self, key: Any):
 
-        super().__init__(4, "public", key)
-
+        super().__init__(key)
         self._sig_size = 64
 
         if not isinstance(self._key, (Ed25519PublicKey, Ed25519PrivateKey)):
             raise ValueError("The key is not Ed25519 key.")
         return
 
-    @classmethod
-    def from_paserk(cls, paserk: str) -> KeyInterface:
-        frags = paserk.split(".")
-        if frags[0] != "k4":
-            raise ValueError("Invalid PASERK version for a v4.public key.")
-        if frags[1] == "public":
-            return cls(Ed25519PublicKey.from_public_bytes(base64url_decode(frags[2])))
-        elif frags[1] == "secret":
-            return cls(
-                Ed25519PrivateKey.from_private_bytes(base64url_decode(frags[2])[0:32])
-            )
-        raise ValueError("Invalid PASERK type for a v4.public key.")
-
     # @classmethod
     # def from_public_bytes(cls, key: bytes):
     #     try:
@@ -142,6 +104,14 @@ class V4Public(KeyInterface):
     #         raise ValueError("Invalid bytes for the key.") from err
     #     return cls(k)
 
+    def to_paserk_id(self) -> str:
+        p = self.to_paserk()
+        h = "k4.pid." if isinstance(self._key, Ed25519PublicKey) else "k4.sid."
+        b = hashlib.blake2b(digest_size=33)
+        b.update((h + p).encode("utf-8"))
+        d = b.digest()
+        return h + base64url_encode(d).decode("utf-8")
+
     def sign(
         self, payload: bytes, footer: bytes = b"", implicit_assertion: bytes = b""
     ) -> bytes:
@@ -175,33 +145,3 @@ class V4Public(KeyInterface):
         except Exception as err:
             raise VerifyError("Failed to verify.") from err
         return m
-
-    def to_paserk(self) -> str:
-        if isinstance(self._key, Ed25519PublicKey):
-            return (
-                "k4.public."
-                + base64url_encode(
-                    self._key.public_bytes(
-                        encoding=serialization.Encoding.Raw,
-                        format=serialization.PublicFormat.Raw,
-                    )
-                ).decode("utf-8")
-            )
-        priv = self._key.private_bytes(
-            encoding=serialization.Encoding.Raw,
-            format=serialization.PrivateFormat.Raw,
-            encryption_algorithm=serialization.NoEncryption(),
-        )
-        pub = self._key.public_key().public_bytes(
-            encoding=serialization.Encoding.Raw,
-            format=serialization.PublicFormat.Raw,
-        )
-        return "k4.secret." + base64url_encode(priv + pub).decode("utf-8")
-
-    def to_paserk_id(self) -> str:
-        p = self.to_paserk()
-        h = "k4.pid." if isinstance(self._key, Ed25519PublicKey) else "k4.sid."
-        b = hashlib.blake2b(digest_size=33)
-        b.update((h + p).encode("utf-8"))
-        d = b.digest()
-        return h + base64url_encode(d).decode("utf-8")
